#
# spec file for package vorbisgain
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 B1 Systems GmbH, Vohburg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vorbisgain
Version:        0.37
Release:        3.1
Summary:        Replay Gain calculator for Ogg Vorbis files
License:        LGPL-2.1-only
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://sjeng.org/vorbisgain.html
Source0:        https://www.sjeng.org/ftp/vorbis/%{name}-%{version}.tar.gz
Patch0:         vorbisgain-c99.patch
BuildRequires:  dos2unix
BuildRequires:  libogg-devel
BuildRequires:  libvorbis-devel

%description
VorbisGain is a utility that uses a psychoacoustic method to correct
the volume of an Ogg Vorbis file to a predefined standardized
loudness.

It is meant as a replacement for the normalization that is commonly
used before encoding. Although normalization will ensure that each
song has the same peak volume, this unfortunately does not say
anything about the apparent loudness of the music, with the end result
being that many normalized files still don't sound equally
loud. VorbisGain uses psychoacoustics to address this
deficiency. Moreover, unlike normalization, it's a lossless procedure
which works by adding tags to the file. Additionally, it will add
hints that can be used to prevent clipping on playback. It is based
upon the ReplayGain technology.

The end result is that playback is both more convenient and of higher
quality compared to a non-VorbisGain'ed file.

%prep
%autosetup -p1
# workaround wrong end-of-line encoding
dos2unix -f COPYING NEWS

%build
%configure --enable-recursive
%make_build

%install
%make_install

%files
%license COPYING
%doc README NEWS
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Tue May 30 2023 Jan Engelhardt <jengelh@inai.de>
- Use noun phrasing in description.
* Sun May 28 2023 Fabian Niepelt <fniepelt@faeyben.de>
- Add --enable-recursive to the configure options
* Thu Dec 24 2020 Matthias Bach <marix@marix.org> - 0.37
- Modernise spec file
* Fri Sep 13 2019 Matthias Bach <marix@marix.org>
- Added vorbisgain-c99.patch ensuring compatibility with C99.
  This solves bsc#1150013.
* Sun Feb 18 2018 avindra@opensuse.org
- Update to 0.37
  * use mktemp for temporary files (fixes a race condition that
    could eat data)
- drop dos2unix fix, fixed upstream
- clean with spec-cleaner
* Mon Aug 21 2017 tchvatal@suse.com
- Cleanup with spec-cleaner
* Mon Aug 21 2017 psychonaut@nothingisreal.com
- Updated to 0.36
- Changed licence from "GPL-2.0" to "LGPL-2.1" to match the actual licence headers in the source files and COPYING file.  (Note that some licence headers reference "the GNU General Public License, version 2.1".  I am assuming that the word "Lesser" has been mistakenly omitted between "GNU" and "General", since there is an LGPL 2.1 but no GPL 2.1, and because the COPYING file is for the LGPL 2.1.  Note that some headers include the "or later" clause while others omit it.)
- Reformatted the description
- Removed obsolete Makefile patch
- Removed unnecessary %%clean
- Replaced manual call to configure with %%configure macro
- Updated project and source URLs
- Applied dos2unix on NEWS file
- Remove merged patch vorbisgain_Makefile_tabs.patch
* Sat Oct 13 2012 seife+obs@b1-systems.com
- enable "--recursive" option
* Mon Aug  8 2011 marix@marix.org
- Updated license information to fix bnc 709981
* Mon Oct  4 2010 marix@marix.org
- Fixed build on Factory (post 11.3)
- Moved changelog to changes file
* Tue Jan 27 2009 marix@marix.org
- Fixed issues raised in review of submit-request #4320
  b) Build requires only contains devel smallest requires package set
  c) Debug information now contained in debug package
* Tue Dec  9 2008 marix@marix.org
- Fixed group tag
- Added RPM_OPT_FLAGS to CFLAGS so binaries are build with the proper flags (debug/no debug, stack protect etc.)
- Added fix for wrong end-of-line-encoding in COPYING file
- Added cleanup after build
- Added strip requirement to make install to shutup RPMLINT
* Tue Nov  4 2008 marix@marix.org
- Fixed packaging of documentation files
* Sun May 11 2008 marix@marix.org
- Initial package creation
